package com.ziplinegreen.vault.Controller;

import com.ziplinegreen.vault.Exception.ResourceNotFoundException;
import com.ziplinegreen.vault.Model.Post;
import com.ziplinegreen.vault.Model.User;
import com.ziplinegreen.vault.Repository.PostRepository;
import com.ziplinegreen.vault.Repository.UserRepository;
import com.ziplinegreen.vault.Service.PostService;
import com.ziplinegreen.vault.Service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.repository.query.Param;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Set;

@RestController
public class PostController {

    private PostService postService;
    private UserController userController;

    @Autowired
    public PostController(PostService postService) {
        this.postService = postService;
    }

    @PostMapping("/{userId}/posts")
    public ResponseEntity<Post> createPost(@PathVariable Long userId, @RequestBody String message){
        return postService.createPost(userId,message);
    }

    @GetMapping("/{userId}/posts")
    public ResponseEntity<Iterable<Post>> getAllPostsByUserId(@PathVariable Long userId) {
        return postService.findAllByUserId(userId);
    }

    @GetMapping("/{userId}/posts/{postId}")
    public ResponseEntity<Post> getPostById(@PathVariable Long userId, @PathVariable Long postId){
        return postService.getPostById(postId);
    }

    @PutMapping("/{userId}/posts/{postId}")
    public ResponseEntity<Post> updatePost(@PathVariable Long userId, @PathVariable Long postId, @RequestBody String message){
        return postService.updatePost(postId, message);
    }

    @DeleteMapping("/{userId}/posts/{postId}")
    public ResponseEntity deletePost(@PathVariable Long userId, @PathVariable Long postId){
        return postService.deletePost(postId);
    }

//    @PutMapping("/users/{userId/posts")
//    public ResponseEntity<Post> updatePost(@PathVariable Long userId, @RequestBody Post post){
//        return postService.updatePost(userId, post);
//    }



//    @PutMapping("/users/{userId}/posts/{postId}")
//    public Post updateComment(@PathVariable (value = "userId") Long userId,
//                                 @PathVariable (value = "postId") Long postId,
//                                 @Valid @RequestBody Post postRequest) {
//        if(!userRepository.existsById(userId)) {
//            throw new ResourceNotFoundException("UserId " + userId + " not found");
//        }
//
//        return postRepository.findById(postId).map(post -> {
//            post.setMessage(postRequest.getMessage());
//            return postRepository.save(post);
//        }).orElseThrow(() -> new ResourceNotFoundException("PostId " + postId + "not found"));
//    }
//
//    @DeleteMapping("/posts/{postId}/comments/{commentId}")
//    public ResponseEntity<?> deleteComment(@PathVariable (value = "userId") Long userId,
//                                           @PathVariable (value = "postId") Long postId) {
//        if(!userRepository.existsById(userId)) {
//            throw new ResourceNotFoundException("UserId " + userId + " not found");
//        }
//
//        return postRepository.findById(postId).map(post -> {
//            postRepository.delete(post);
//            return ResponseEntity.ok().build();
//        }).orElseThrow(() -> new ResourceNotFoundException("PostId " + postId + " not found"));
//    }
}


//    @PutMapping("/{userId}/posts")
//    public ResponseEntity<?> addPost(@PathVariable Long userId, @RequestBody String message){
//        Post post = new Post(message, userId);
//        return userService.addpost(userId, post);
//    }